@@ -89,7 +89,7 @@ bool Controller::widgetInstalled() const {
     bool isInstalled = false;
 
 #ifdef Q_WS_MAEMO_5
-    if (QFile::exists("/usr/share/hildon-desktop/qmltube-widget")) {
+    if (QFile::exists("/usr/lib/hildon-desktop/qmltube-widget")) {
         isInstalled = true;
     }
 #endif
@@ -171,7 +171,7 @@ void Controller::playVideo(const QString &url) {
         QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
         dbus_iface.call("mime_open", url);
     }
-    emit playbackStarted();
+    emit playbackStarted(url);
 
 #else
     QStringList args;
@@ -179,6 +179,7 @@ void Controller::playVideo(const QString &url) {
     QProcess *player = new QProcess();
     connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
     player->start("/usr/bin/mplayer", args);
+    emit playbackStarted(url);
 #endif
 }
 
