@@ -24,15 +24,18 @@ function restoreSettings() {
 function getArchiveVideos() {
     /* Retrieve archive videos and populate the list model */
 
-    var videos = Settings.getAllArchiveVideos();
+    var videos = Settings.getAllArchiveVideos("date", "ASC");
     for (var i = 0; i < videos.length ; i++) {
-        archiveModel.insert(0, { "filePath": videos[i][0], "title": videos[i][1],
-                            "thumbnail": videos[i][2], "quality": videos[i][3],
-                            "isNew": videos[i][4] });
+        var archiveItem = { "filePath": videos[i][0], "title": videos[i][1],
+            "thumbnail": videos[i][2], "quality": videos[i][3],
+            "isNew": videos[i][4], "date": videos[i][5] };
+        archiveModel.insert(0, archiveItem);
     }
 }
 
 function moveToArchive(video) {
+    var date = new Date();
+    video["date"] = date.valueOf();
     Settings.addVideoToArchive(video);
     archiveModel.insert(0, video);
     downloadModel.remove(downloadModel.currentDownload);
