@@ -19,6 +19,9 @@ function initialize() {
                         tx.executeSql('DROP TABLE IF EXISTS settings');
                         tx.executeSql('CREATE TABLE settings(setting TEXT UNIQUE, value TEXT)');
                     }
+                    if (getSetting("addDateToArchive") == "unknown") {
+                        tx.executeSql('ALTER TABLE archive ADD COLUMN date INTEGER');
+                    }
                     setDefaultSettings();
                 });
 }
@@ -142,7 +145,8 @@ function setDefaultSettings() {
                     [ "widgetFeedTwo", "_MOST_VIEWED_FEED" ],
                     [ "widgetFeedThree", "archive" ],
                     [ "widgetFeedFour", "_NEW_SUB_VIDEOS_FEED" ],
-                    [ "resetSettings", "no"] ];
+                    [ "resetSettings", "no"],
+                    [ "addDateToArchive", "no"] ];
 
     for (var i = 0; i < settings.length; i++) {
         var setting = settings[i][0];
@@ -253,8 +257,8 @@ function addVideoToArchive(video) {
     var db = getDatabase();
     var res = "";
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('INSERT OR REPLACE INTO archive VALUES (?, ?, ?, ?, ?);', [ video.filePath, video.title,
-                                                                                                         video.thumbnail, video.quality, video.isNew ]);
+                       var rs = tx.executeSql('INSERT OR REPLACE INTO archive VALUES (?, ?, ?, ?, ?, ?);', [ video.filePath, video.title,
+                                                                                                         video.thumbnail, video.quality, video.isNew, video.date ]);
                        if (rs.rowsAffected > 0) {
                            res = "OK";
                        }
@@ -276,7 +280,7 @@ function getArchiveVideo(filePath) {
                        var rs = tx.executeSql('SELECT * FROM archive WHERE filePath=?;', [ filePath ]);
                        if (rs.rows.length > 0) {
                            res = [ rs.rows.item(0).filePath, rs.rows.item(0).title, rs.rows.item(0).thumbnail,
-                                  rs.rows.item(0).quality, rs.rows.item(0).isNew ];
+                                  rs.rows.item(0).quality, rs.rows.item(0).isNew, rs.rows.item(0).date ];
                        }
                    }
                    );
@@ -284,7 +288,7 @@ function getArchiveVideo(filePath) {
     return res
 }
 
-function getAllArchiveVideos() {
+function getAllArchiveVideos(column, order) {
     /* Retrieve all archive videos from the database */
 
     var db = getDatabase();
@@ -292,7 +296,7 @@ function getAllArchiveVideos() {
     var downloadPath = getSetting("downloadPath");
     var path;
     db.transaction(function(tx) {
-                       var rs = tx.executeSql('SELECT * FROM archive;');
+                       var rs = tx.executeSql('SELECT * FROM archive ORDER BY ' + column + ' ' + order + ';');
                        if (rs.rows.length > 0) {
                            for(var i = 0; i < rs.rows.length; i++) {
                                path = Controller.archiveFileExists(rs.rows.item(i).filePath, downloadPath);
@@ -301,7 +305,7 @@ function getAllArchiveVideos() {
                                }
                                else {
                                    res[i] = [ rs.rows.item(i).filePath, rs.rows.item(i).title, rs.rows.item(i).thumbnail,
-                                             rs.rows.item(i).quality, rs.rows.item(i).isNew ];
+                                             rs.rows.item(i).quality, rs.rows.item(i).isNew, rs.rows.item(i).date ];
                                    if (path != "Unchanged") {
                                        res[i][0] = path;
                                        editArchiveVideo(rs.rows.item(i).filePath, "filePath", path);
@@ -318,13 +322,16 @@ function getAllArchiveVideos() {
 function editArchiveVideo(filePath, attribute, newValue) {
     /* Set the attribute of the video with matching filePath to newValue */
 
-    var attributes = [ "filePath", "title", "thumbnail", "quality", "isNew"];
+    var attributes = [ "filePath", "title", "thumbnail", "quality", "isNew", "date" ];
     var video = getArchiveVideo(filePath);
     var modifiedVideo = {};
     for (var i = 0; i < attributes.length; i++) {
         modifiedVideo[attributes[i]] = video[i];
     }
     modifiedVideo[attribute] = newValue;
+    if (!(modifiedVideo["date"] > 0)) {
+        modifiedVideo["date"] = 0;
+    }
     if (attribute == "filePath") {
         deleteVideoFromArchive(filePath);
     }
