@@ -46,11 +46,11 @@ void YouTube::checkLogin() {
     QList<QByteArray> sp = response.split('=');
     QByteArray token = sp.last().trimmed();
 
-    if (sp.first() == "Error") {
-        setCurrentUser("");
-        emit alert(sp.first() + ": " + sp.at(1).split('\n').first());
-    }
-    else if ((token.isEmpty()) || (token == "BadAuthentication")) {
+//    if (sp.first() == "Error") {
+//        setCurrentUser("");
+//        emit alert(sp.first() + ": " + sp.at(1).split('\n').first());
+//    }
+    if ((token.isEmpty()) || (token == "BadAuthentication")) {
         setCurrentUser("");
         emit alert(tr("Authentication failed"));
     }
@@ -255,7 +255,7 @@ void YouTube::addToFavourites(const QString &videoId) {
 void YouTube::deleteFromFavourites(const QString &favouriteId) {
     QUrl url("http://gdata.youtube.com/feeds/api/users/" + currentUser + "/favorites/" + favouriteId);
     deleteRequest(url);
-
+    connect(this, SIGNAL(postSuccessful()), this, SIGNAL(deletedFromFavourites()));
 }
 
 void YouTube::addToPlaylist(const QString &videoId, const QString &playlistId) {
@@ -272,6 +272,7 @@ void YouTube::addToPlaylist(const QString &videoId, const QString &playlistId) {
 void YouTube::deleteFromPlaylist(const QString &playlistId, const QString &playlistVideoId) {
     QUrl url("http://gdata.youtube.com/feeds/api/playlists/" + playlistId + "/" + playlistVideoId);
     deleteRequest(url);
+    connect(this, SIGNAL(postSuccessful()), this, SIGNAL(deletedFromPlaylist()));
 }
 
 void YouTube::createNewPlaylist(const QString &title, const QString &description, const bool &isPrivate) {
@@ -394,40 +395,3 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
     manager->deleteLater();
 }
 
-void YouTube::parseVideoPage() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
-
-    QMap<int, QByteArray> formats;
-    QByteArray response = reply->readAll();
-    response = response.simplified().replace(QByteArray(" "), QByteArray(""));
-    int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
-    int pos2 = response.indexOf('\"', pos);
-    response = response.mid(pos, pos2 - pos);
-    QList<QByteArray> parts = response.split('|');
-    int key = parts.first().toInt();
-    for (int i = 1; i < parts.length(); i++) {
-        QByteArray part = parts[i];
-        QList<QByteArray> keyAndValue = part.split(',');
-        QByteArray url = keyAndValue.first().replace(QByteArray("\\/"), QByteArray("/")).replace(QByteArray("\\u0026"), QByteArray("&"));
-        formats[key] = url;
-        key = keyAndValue.last().toInt();
-    }
-    QList<int> flist;
-    flist << 22 << 35 << 34 << 18 << 5;
-    QByteArray videoUrl = "";
-    int index = flist.indexOf(playbackFormat);
-    while ((videoUrl == "") && index < flist.size()) {
-        videoUrl = formats.value(flist.at(index), "");
-        index++;
-    }
-    if (videoUrl == "") {
-        emit alert(tr("Error: Unable to retrieve video"));
-        emit videoUrlError();
-    }
-    else {
-        emit gotVideoUrl(QString(videoUrl));
-        qDebug() << videoUrl;
-    }
-    reply->deleteLater();
-}
-
